pub struct Remowt(/* private fields */);Implementations
Sourceimpl Remowt
impl Remowt
pub async fn open_shell( &self, term: &str, cols: u16, rows: u16, escalate: bool, ) -> Result<RemowtShell>
Sourceimpl Remowt
impl Remowt
pub async fn spawn(&self, opts: SpawnOptions) -> Result<RemowtChild>
pub fn cmd(&self, program: impl AsRef<str>) -> RemowtCommand
Sourceimpl Remowt
impl Remowt
Sourcepub async fn connect(
host: &str,
bundle: &AgentBundle,
remowt_user: String,
) -> Result<Self>
pub async fn connect( host: &str, bundle: &AgentBundle, remowt_user: String, ) -> Result<Self>
Connect to the remote host over ssh, detect the architecture and deploy the required agent binary.
Sourcepub async fn connect_local(bundle: &AgentBundle, user: String) -> Result<Self>
pub async fn connect_local(bundle: &AgentBundle, user: String) -> Result<Self>
“Connect” to the local machine’s agent, by starting the agent binary locally.
Sourcepub fn ssh(&self) -> Option<Arc<Handle<SshHandler>>>
pub fn ssh(&self) -> Option<Arc<Handle<SshHandler>>>
Get the handle to the underlying russh session handle.
pub fn rpc(&self) -> Rpc<BifConfig>
pub async fn load_plugin(&self, id: u16, name: &str) -> Result<()>
pub async fn run0_load_plugin_path(&self, id: u16, path: &str) -> Result<()>
pub fn plugin_endpoints<R: RemoteEndpoints<BifConfig>>(&self, id: u16) -> R
pub fn endpoints<R: RemoteEndpoints<BifConfig>>(&self) -> R
pub async fn run0_endpoints<R: RemoteEndpoints<BifConfig>>(&self) -> Result<R>
Sourcepub fn runtime_dir(&self) -> Utf8PathBuf
pub fn runtime_dir(&self) -> Utf8PathBuf
XDG_RUNTIME_DIR on the remote machine.
Sourcepub async fn bind_runtime_unix(
&self,
hint: &str,
) -> Result<(RemowtListener, Utf8PathBuf)>
pub async fn bind_runtime_unix( &self, hint: &str, ) -> Result<(RemowtListener, Utf8PathBuf)>
Bind unix listener socket on the remote machine with auto-generated path, returning the path.
Sourcepub async fn bind_unix(&self, path: &Utf8Path) -> Result<RemowtListener>
pub async fn bind_unix(&self, path: &Utf8Path) -> Result<RemowtListener>
Bind unix listener socket on the remote machine on the specified path.